<?php
use CRM_Nbrcivirules_ExtensionUtil as E;

/**
 * Class for form processing set eligible status on all studies for volunteer
 *
 * @author Erik Hommel (CiviCooP) <erik.hommel@civicoop.org>
 * @date 16 Apr 2020
 * @license AGPL-3.0
 */

class CRM_Nbrcivirules_Actions_Contact_Form_SetEligibilityStatus extends CRM_CivirulesActions_Form_Form {

  /**
   * Overridden parent method to build form
   *
   * @access public
   */
  public function buildQuickForm() {
    $this->add('hidden', 'rule_action_id');
    $actionOptions = ['Add', 'Remove'];
    $this->addRadio('nbr_eligible_status_action', E::ts('Add or Remove: '), $actionOptions);
    $this->add('select', 'nbr_eligible_status_id', ts('Set Eligible Status to:'), CRM_Nihrbackbone_Utils::getOptionValueList('nihr_eligible_status'), TRUE, array('class' => 'crm-select2'));
    $this->addButtons([
      ['type' => 'next', 'name' => ts('Save'), 'isDefault' => TRUE,],
      ['type' => 'cancel', 'name' => ts('Cancel')],
    ]);
  }

  /**
   * Overridden parent method to set default values
   *
   * @return array $defaultValues
   * @access public
   */
  public function setDefaultValues() {
    $defaultValues = parent::setDefaultValues();
    if ($this->ruleActionId) {
      $defaults['rule_action_id'] = $this->ruleActionId;
    }
    $data = unserialize($this->ruleAction->action_params);
    if (isset($data['nbr_eligible_status_id'])) {
      $defaultValues['nbr_eligible_status_id'] = $data['nbr_eligible_status_id'];
    }
    if (isset($data['nbr_eligible_status_action'])) {
      $defaultValues['nbr_eligible_status_action'] = $data['nbr_eligible_status_action'];
    }
    return $defaultValues;
  }

  /**
   * Overridden parent method to process form data after submission
   *
   * @throws Exception when rule condition not found
   * @access public
   */
  public function postProcess() {
    $data['nbr_eligible_status_id'] = str_replace(' ', '', $this->_submitValues['nbr_eligible_status_id']);
    $data['nbr_eligible_status_action'] = $this->_submitValues['nbr_eligible_status_action'];
    $this->ruleAction->action_params = serialize($data);
    $this->ruleAction->save();
    parent::postProcess();
  }
}
